#[repr(transparent)]pub struct Aplltestctrl(pub u32);Expand description
APLL Test Control Register.
Tuple Fields
0: u32Implementations
Sourceimpl Aplltestctrl
impl Aplltestctrl
Sourcepub const fn set_nfunctest(&mut self, val: u8)
pub const fn set_nfunctest(&mut self, val: u8)
Input to functional test the predivider (N-divider).
Sourcepub const fn mfunctest(&self) -> u16
pub const fn mfunctest(&self) -> u16
Input to functional test the feedback-divider (M-divider).
Sourcepub const fn set_mfunctest(&mut self, val: u16)
pub const fn set_mfunctest(&mut self, val: u16)
Input to functional test the feedback-divider (M-divider).
Sourcepub const fn set_pfunctest(&mut self, val: u8)
pub const fn set_pfunctest(&mut self, val: u8)
Input to functional test the postdivider (P-divider).
Sourcepub const fn set_testv_en(&mut self, val: bool)
pub const fn set_testv_en(&mut self, val: bool)
Enable test mux.
Sourcepub const fn testv_sel(&self) -> AplltestctrlTestvSel
pub const fn testv_sel(&self) -> AplltestctrlTestvSel
Select analog signal channel that need to be test.
Sourcepub const fn set_testv_sel(&mut self, val: AplltestctrlTestvSel)
pub const fn set_testv_sel(&mut self, val: AplltestctrlTestvSel)
Select analog signal channel that need to be test.
Sourcepub const fn set_bypasspll(&mut self, val: bool)
pub const fn set_bypasspll(&mut self, val: bool)
Bypass PLL.