nxp-pac

Crates

git

Versions

mcxa256

Flavors

Splltestctrl

Struct Splltestctrl 

#[repr(transparent)]
pub struct Splltestctrl(pub u32);
SPLL Test Control Register.

Tuple Fields

0: u32

Implementations

Source

impl Splltestctrl

pub const fn nfunctest(&self) -> u8

Input to functional test the predivider (N-divider).

pub const fn set_nfunctest(&mut self, val: u8)

Input to functional test the predivider (N-divider).

pub const fn mfunctest(&self) -> u16

Input to functional test the feedback divider (M-divider).

pub const fn set_mfunctest(&mut self, val: u16)

Input to functional test the feedback divider (M-divider).

pub const fn pfunctest(&self) -> u8

Input to functional test the postdivider (P-divider).

pub const fn set_pfunctest(&mut self, val: u8)

Input to functional test the postdivider (P-divider).

pub const fn testv_en(&self) -> bool

Enable test mux.

pub const fn set_testv_en(&mut self, val: bool)

Enable test mux.

pub const fn testv_sel(&self) -> SplltestctrlTestvSel

Select analog signal channel that need to be test.

pub const fn set_testv_sel(&mut self, val: SplltestctrlTestvSel)

Select analog signal channel that need to be test.

pub const fn bypasspll(&self) -> bool

Bypass PLL.

pub const fn set_bypasspll(&mut self, val: bool)

Bypass PLL.